@@ -1,4 +1,4 @@
-# Copyright (c) Acconeer AB, 2022
+# Copyright (c) Acconeer AB, 2022-2023
 # All rights reserved
 
 import acconeer.exptool as et
@@ -8,8 +8,7 @@ from acconeer.exptool import a121
 args = a121.ExampleArgumentParser().parse_args()
 et.utils.config_logging(args)
 
-client = a121.Client(**a121.get_client_args(args))
-client.connect()
+client = a121.Client.open(**a121.get_client_args(args))
 
 sensor_config = a121.SensorConfig(
     subsweeps=[
@@ -41,4 +40,4 @@ for i in range(3):
     print(result.subframes)
 
 client.stop_session()
-client.disconnect()
+client.close()
