@@ -1,4 +1,4 @@
-# Copyright (c) Acconeer AB, 2022
+# Copyright (c) Acconeer AB, 2022-2023
 # All rights reserved
 
 from .entities import (
@@ -8,6 +8,7 @@ from .entities import (
     Criticality,
     IdleState,
     Metadata,
+    MockInfo,
     PersistentRecord,
     Profile,
     Record,
@@ -15,20 +16,24 @@ from .entities import (
     SensorCalibration,
     SensorConfig,
     SensorInfo,
+    SerialInfo,
     ServerInfo,
     SessionConfig,
+    SocketInfo,
     StackedResults,
     SubsweepConfig,
+    USBInfo,
     ValidationError,
     ValidationResult,
     ValidationWarning,
     complex_array_to_int16_complex,
     int16_complex_array_to_complex,
 )
-from .mediators import ClientBase, ClientError, Recorder
+from .mediators import Recorder
 from .peripherals import (
     _H5PY_STR_DTYPE,
     Client,
+    ClientError,
     H5Record,
     H5Recorder,
     InMemoryRecord,
