@@ -322,7 +322,7 @@ class SensorConfig:
                 ValidationError(
                     self,
                     "frame_rate",
-                    "Frame rate must unset (`None`) to use continuous sweep mode.",
+                    "Frame rate must be unset to use continuous sweep mode.",
                 )
             )
         if self.sweep_rate is None:
@@ -380,10 +380,10 @@ class SensorConfig:
                     ValidationError(
                         self,
                         "frame_rate",
-                        "The frame rate is set faster than what the sweep rate allows."
-                        + f"Frame rate: {self.frame_rate} Hz\n"
+                        "The frame rate is set higher than what the sweep rate allows.\n"
+                        + f"Frame rate: {self.frame_rate:.2f} Hz\n"
                         + "Sweep rate / sweeps per frame: "
-                        + f"{self.sweep_rate / self.sweeps_per_frame} Hz",
+                        + f"{self.sweep_rate / self.sweeps_per_frame:.2f} Hz",
                     )
                 )
 
@@ -401,7 +401,7 @@ class SensorConfig:
 
     def _validate_required_buffer_usage(self) -> list[ValidationResult]:
         BUFFER_SIZE = 4096
-        ERROR_MSG = "This config would have required buffer size {}, but the max is {}"
+        ERROR_MSG = "Required buffer size is too large: {}/{}."
 
         buffer_size_available = (
             (BUFFER_SIZE // 2) - 1 if self.double_buffering else BUFFER_SIZE - 1
@@ -416,14 +416,16 @@ class SensorConfig:
                 ValidationError(
                     self,
                     "sweeps_per_frame",
-                    ERROR_MSG.format(required_buffer_size, buffer_size_available),
+                    ERROR_MSG.format(required_buffer_size, buffer_size_available)
+                    + " Decreasing sweeps per frame reduces buffer usage.",
                 ),
             )
             validation_results.extend(
                 ValidationError(
                     subsweep_config,
                     "num_points",
-                    ERROR_MSG.format(required_buffer_size, buffer_size_available),
+                    ERROR_MSG.format(required_buffer_size, buffer_size_available)
+                    + " Decreasing number of points reduces buffer usage.",
                 )
                 for subsweep_config in self.subsweeps
             )
@@ -530,6 +532,9 @@ class SensorConfig:
         If enabled, the sensor buffer will be split in two halves reducing the
         maximum number of samples. A frame can be read while sampling is done into the
         other buffer.
+
+        When using double buffering, measurements coinciding with SPI activity may have distorted
+        phase. To mitigate this issue, applying a median filter is recommended.
         """
 
         return self._double_buffering
