@@ -1,8 +1,10 @@
-# Copyright (c) Acconeer AB, 2022
+# Copyright (c) Acconeer AB, 2022-2023
 # All rights reserved
 
 from __future__ import annotations
 
+import typing as t
+
 import attrs
 import numpy as np
 import numpy.typing as npt
@@ -35,7 +37,7 @@ class StackedResults:
     frame_delayed: NDArrayBool = attrs.field(eq=attrs_ndarray_eq)
     calibration_needed: NDArrayBool = attrs.field(eq=attrs_ndarray_eq)
     temperature: NDArrayBool = attrs.field(eq=attrs_ndarray_eq)
-    _frame: npt.NDArray = attrs.field(eq=attrs_ndarray_eq)
+    _frame: npt.NDArray[t.Any] = attrs.field(eq=attrs_ndarray_eq)
 
     tick: NDArrayInt = attrs.field()
 
