@@ -8,11 +8,18 @@ from typing import List, Optional
 import attrs
 
 import acconeer.exptool as et
-from acconeer.exptool.a121._core.entities import ClientInfo, SensorCalibration, SessionConfig
-from acconeer.exptool.a121._core.mediators import BufferedLink, ClientError
+from acconeer.exptool.a121._core.entities import (
+    ClientInfo,
+    SensorCalibration,
+    SerialInfo,
+    SessionConfig,
+    USBInfo,
+)
+from acconeer.exptool.a121._core.mediators import BufferedLink
 from acconeer.exptool.a121._core.utils import iterate_extended_structure
 from acconeer.exptool.utils import SerialDevice, USBDevice  # type: ignore[import]
 
+from .common_client import ClientError
 from .links import AdaptedSerialLink, AdaptedSocketLink, AdaptedUSBLink, NullLink
 
 
@@ -30,13 +37,6 @@ def get_one_serial_device() -> SerialDevice:
         return acconeer_serial_devices[0]
 
 
-def determine_serial_device(serial_port: Optional[str]) -> str:
-    if serial_port is None:
-        return str(get_one_serial_device().port)
-    else:
-        return serial_port
-
-
 def get_one_usb_device(only_accessible: bool = False) -> USBDevice:
     usb_devices = et.utils.get_usb_devices(only_accessible=only_accessible)
     if not usb_devices:
@@ -48,33 +48,33 @@ def get_one_usb_device(only_accessible: bool = False) -> USBDevice:
         return usb_devices[0]
 
 
-def determine_usb_device(usb_device: Optional[USBDevice]) -> USBDevice:
-    if usb_device is None:
-        return get_one_usb_device(only_accessible=True)
-    else:
-        return usb_device
-
-
 def link_factory(client_info: ClientInfo) -> BufferedLink:
 
-    if client_info.ip_address is not None:
-        return AdaptedSocketLink(host=client_info.ip_address, port=client_info.tcp_port)
-
-    if client_info.serial_port is not None:
-        link = AdaptedSerialLink(
-            port=client_info.serial_port,
+    if client_info.socket is not None:
+        return AdaptedSocketLink(
+            host=client_info.socket.ip_address, port=client_info.socket.tcp_port
         )
 
-        return link
-
-    if client_info.usb_device is not None:
-        link = AdaptedUSBLink(
-            vid=client_info.usb_device.vid,
-            pid=client_info.usb_device.pid,
-            serial=client_info.usb_device.serial,
+    if client_info.serial is not None:
+        return AdaptedSerialLink(
+            port=client_info.serial.port,
         )
 
-        return link
+    if client_info.usb is not None:
+        usb_device = None
+        if client_info.usb.serial_number is not None:
+            usb_device = et.utils.get_usb_device_by_serial(
+                client_info.usb.serial_number, only_accessible=False
+            )
+        else:
+            usb_device = get_one_usb_device()
+
+        if usb_device is not None:
+            return AdaptedUSBLink(
+                vid=usb_device.vid,
+                pid=usb_device.pid,
+                serial=usb_device.serial,
+            )
 
     return NullLink()
 
@@ -82,22 +82,26 @@ def link_factory(client_info: ClientInfo) -> BufferedLink:
 def autodetermine_client_link(client_info: ClientInfo) -> ClientInfo:
     error_message = ""
     try:
-        client_info = attrs.evolve(
+        usb_info = client_info.usb
+        if usb_info is None:
+            usb_device = get_one_usb_device(only_accessible=True)
+            usb_info = USBInfo(
+                vid=usb_device.vid, pid=usb_device.pid, serial_number=usb_device.serial
+            )
+        return attrs.evolve(
             client_info,
-            usb_device=determine_usb_device(client_info.usb_device),
+            usb=usb_info,
         )
 
-        return client_info
     except ClientError as exc:
         error_message += f"\nUSB: {str(exc)}"
         pass
 
     try:
-        client_info = attrs.evolve(
-            client_info,
-            serial_port=determine_serial_device(client_info.serial_port),
-        )
-        return client_info
+        serial_info = client_info.serial
+        if serial_info is None:
+            serial_info = SerialInfo(port=str(get_one_serial_device().port))
+        return attrs.evolve(client_info, serial=serial_info)
     except ClientError as exc:
         error_message += f"\nSerial: {str(exc)}"
 
