@@ -236,13 +236,9 @@ class BackendPlugin(DetectorBackendPluginBase[SharedState]):
             raise RuntimeError
         detector_result = self._detector_instance.get_next()
 
-        self._frame_count += 1
-
         processor_result = self._processor_instance.process(result=detector_result)
 
         assert self.client is not None
-        self.callback(GeneralMessage(name="rate_stats", data=self.client._rate_stats))
-        self.callback(GeneralMessage(name="frame_count", data=self._frame_count))
         self.callback(
             GeneralMessage(
                 name="plot",
@@ -444,14 +440,6 @@ class ViewPlugin(DetectorViewPluginBase):
             "Current configuration does not match the configuration "
             + "used during detector calibration. Run detector calibration."
         ),
-        DetailedStatus.INVALID_DETECTOR_CONFIG_RANGE: (
-            "Invalid detector config. Valid measurement"
-            + " range is "
-            + str(Detector.MIN_DIST_M)
-            + "-"
-            + str(Detector.MAX_DIST_M)
-            + "m."
-        ),
     }
 
     def __init__(self, app_model: AppModel, view_widget: QWidget) -> None:
@@ -617,7 +605,9 @@ class ViewPlugin(DetectorViewPluginBase):
             ready_for_session
             and not detector_status.detector_state == DetailedStatus.SENSOR_IDS_NOT_UNIQUE
         )
-        self.start_button.setEnabled(ready_for_session and detector_status.ready_to_start)
+        self.start_button.setEnabled(
+            ready_for_session and detector_status.ready_to_start and self.config_editor.is_ready
+        )
         self.stop_button.setEnabled(app_model.plugin_state == PluginState.LOADED_BUSY)
 
     def _on_config_update(self, config: DetectorConfig) -> None:
@@ -640,7 +630,6 @@ class ViewPlugin(DetectorViewPluginBase):
 
     def _on_calibrate_detector(self) -> None:
         self.app_model.put_backend_plugin_task("calibrate_detector")
-        self.app_model.set_plugin_state(PluginState.LOADED_STARTING)
 
     def _send_defaults_request(self) -> None:
         self.app_model.put_backend_plugin_task("restore_defaults")
