@@ -10,7 +10,7 @@ import shutil
 import time
 from enum import Enum
 from pathlib import Path
-from typing import Any, Callable, List, Optional, Tuple, Union
+from typing import Any, Callable, Dict, List, Optional, Tuple, Union
 from uuid import UUID
 
 import attrs
@@ -202,9 +202,7 @@ class AppModel(QObject):
 
     backend_plugin_state: Any
 
-    connection_state: ConnectionState
     connection_warning: Optional[str]
-    plugin_state: PluginState
     available_serial_devices: List[SerialDevice]
     available_usb_devices: List[USBDevice]
 
@@ -235,9 +233,9 @@ class AppModel(QObject):
 
         self.backend_plugin_state = None
 
-        self.connection_state = ConnectionState.DISCONNECTED
+        self._connection_state = ConnectionState.DISCONNECTED
         self.connection_warning = None
-        self.plugin_state = PluginState.UNLOADED
+        self._plugin_state = PluginState.UNLOADED
         self._serial_connection_device = None
         self._usb_connection_device = None
         self.available_serial_devices = []
@@ -245,6 +243,16 @@ class AppModel(QObject):
 
         self.saveable_file = None
 
+    @property
+    def plugin_state(self) -> PluginState:
+        """Read-only property of the plugin state"""
+        return self._plugin_state
+
+    @property
+    def connection_state(self) -> ConnectionState:
+        """Read-only property of the connection state"""
+        return self._connection_state
+
     def start(self) -> None:
         self._listener.start()
         self._port_updater.start()
@@ -346,13 +354,13 @@ class AppModel(QObject):
 
     def _handle_backend_message(self, message: Message) -> None:
         if isinstance(message, ConnectionStateMessage):
-            log.debug("Got backend connection state message")
-            self.connection_state = message.state
+            log.debug(f"Got backend connection state message {message.state}")
+            self._connection_state = message.state
             self.connection_warning = message.warning
             self.broadcast()
         elif isinstance(message, PluginStateMessage):
-            log.debug("Got backend plugin state message")
-            self.plugin_state = message.state
+            log.debug(f"Got plugin state message {message.state}")
+            self._plugin_state = message.state
             self.broadcast()
         elif isinstance(message, BackendPluginStateMessage):
             log.debug("Got backend plugin state message")
@@ -550,24 +558,32 @@ class AppModel(QObject):
         return current_port, False
 
     def connect_client(self, auto: bool = False) -> None:
+        open_client_parameters: Dict[str, Any]
+
         if self.connection_interface == ConnectionInterface.SIMULATED:
-            client_info = a121.ClientInfo(mock=True)
+            open_client_parameters = {"mock": True}
         elif self.connection_interface == ConnectionInterface.SOCKET:
-            client_info = a121.ClientInfo(ip_address=self.socket_connection_ip)
+            open_client_parameters = {"ip_address": self.socket_connection_ip}
         elif (
             self.connection_interface == ConnectionInterface.SERIAL
             and self.serial_connection_device is not None
         ):
-            client_info = a121.ClientInfo(
-                serial_port=self.serial_connection_device.port,
-                override_baudrate=self.overridden_baudrate,
-            )
-        elif self.connection_interface == ConnectionInterface.USB:
-            client_info = a121.ClientInfo(usb_device=self.usb_connection_device)
+            open_client_parameters = {
+                "serial_port": self.serial_connection_device.port,
+                "override_baudrate": self.overridden_baudrate,
+            }
+        elif (
+            self.connection_interface == ConnectionInterface.USB
+            and self.usb_connection_device is not None
+        ):
+            if self.usb_connection_device.serial is not None:
+                open_client_parameters = {"usb_device": self.usb_connection_device.serial}
+            else:
+                open_client_parameters = {"usb_device": True}
         else:
             raise RuntimeError
 
-        log.debug(f"Connecting client with {client_info}")
+        log.debug(f"Connecting client with {open_client_parameters}")
 
         on_error = self.emit_error
         if auto:
@@ -575,16 +591,14 @@ class AppModel(QObject):
 
         self._put_backend_task(
             "connect_client",
-            {"client_info": client_info},
+            {"open_client_parameters": open_client_parameters},
             on_error=on_error,
         )
-        self.connection_state = ConnectionState.CONNECTING
         self.connection_warning = None
         self.broadcast()
 
     def disconnect_client(self) -> None:
         self._put_backend_task("disconnect_client", {})
-        self.connection_state = ConnectionState.DISCONNECTING
         self.connection_warning = None
         self._a121_server_info = None
         self.broadcast()
@@ -674,10 +688,6 @@ class AppModel(QObject):
         self._persistent_state.usb_connection_device = device
         self.broadcast()
 
-    def set_plugin_state(self, state: PluginState) -> None:
-        self.plugin_state = state
-        self.broadcast()
-
     def set_autoconnect_enabled(self, autoconnect_enabled: bool) -> None:
         self._persistent_state.autoconnect_enabled = autoconnect_enabled
         self.broadcast()
@@ -695,9 +705,6 @@ class AppModel(QObject):
         self.sig_load_plugin.emit(None)
         self._update_saveable_file(None)
         self.backend_plugin_state = None
-        if self.plugin is not None:
-            self.plugin_state = PluginState.UNLOADING
-
         self.broadcast()
 
         self._put_backend_task("unload_plugin", {}, on_error=self.emit_error)
@@ -719,7 +726,6 @@ class AppModel(QObject):
                 on_error=self.emit_error,
             )
             self.put_backend_plugin_task("load_from_cache", {})
-            self.plugin_state = PluginState.LOADING
 
         self.sig_load_plugin.emit(plugin)
         self.plugin = plugin
@@ -767,8 +773,6 @@ class AppModel(QObject):
 
         self.load_plugin(plugin)
         self.put_backend_plugin_task("load_from_file", {"path": path}, on_error=self.emit_error)
-        self.plugin_state = PluginState.LOADED_STARTING
-        self.broadcast()
 
     def _find_plugin(self, find_key: Optional[str]) -> PluginSpec:  # TODO: Also find by generation
         if find_key is None:
